# spike2py_reflex


## TODO

* create an interactive script to help researcher create correct reflex json file for study

* determine if code runs when unneeded details (e.g. train windows in a study without trains) not included in json

* create script that will allow users to generate various json files based on an interactive shell prompt and answer system.
